#!/bin/sh

kernel=$(uname -r)

# defaults
if [ "$kernel" == "2.6.28.10-power49" ]; then
DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
else
if [ "$kernel" == "2.6.28.10-power48" ]; then
DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
else
if [ "$kernel" == "2.6.28.10-power47" ]; then
DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
else
if [ "$kernel" == "2.6.28.10-power46-wl" ]; then
DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
else
if [ "$kernel" == "2.6.28.10-power40-wl" ]; then
DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp-old"
else
DRIVERPATH="/opt/wifi-pwner/compat-wireless/kp"
fi
fi
fi
fi
fi

# Unload wifi modules
rmmod wl1251_spi 2>/dev/null
rmmod wl1251 2>/dev/null
rmmod wl12xx 2>/dev/null
rmmod mac80211 2>/dev/null
rmmod cfg80211 2>/dev/null
rmmod rfkill_backport 2>/dev/null
rmmod compat_firmware_class 2>/dev/null
rmmod compat 2>/dev/null
# Load bleeding-edge wl1251
insmod $DRIVERPATH/compat.ko
insmod $DRIVERPATH/rfkill_backport.ko
insmod $DRIVERPATH/cfg80211.ko
insmod $DRIVERPATH/mac80211.ko
insmod $DRIVERPATH/wl1251.ko
insmod $DRIVERPATH/wl1251_spi.ko

echo "Custom wl1251 module loaded (with injection) :)"
sleep 1
